@@ -121,7 +121,7 @@ def activate_line(x, y, z, command, tile_type=""):
 
 		if switch2 == "name":
 			#note that name is not interpreted as a command. See above.
-			g.name = set_to
+			g.name = interpret_line(set_to)
 		elif switch2 == "hp":
 			g.hp = g.hp + int(set_to)
 			if g.hp >= g.adj_maxhp: g.hp = g.adj_maxhp
