@@ -8,7 +8,6 @@ from Tkinter import *
 #needed for the buttons.
 import ImageTk
 import Image
-import os.path #for checking on existance of monster pixs.
 
 import g
 import main
@@ -56,6 +55,10 @@ base_mon_hp_width = []
 base_mon_hp_y_start = []
 base_mon_hp_height = []
 
+#the currently selected monster.
+active_button = -1
+
+
 #refreshes the battle view. Call after changing anything.
 def refresh():
 	#hp/ep bars
@@ -73,6 +76,14 @@ def refresh():
 				base_mon_hp_start[i] + temp_width,
 				base_mon_hp_y_start[i]+5)
 
+	#Draw the monster selection arrow if needed.
+	canvas_mon_pic.delete(canvas_mon_pic.find_withtag("monster_arrow"))
+	global active_button
+	if active_button != -1:
+		canvas_mon_pic.create_image(
+			base_mon_hp_start[active_button],
+			base_mon_hp_y_start[active_button]-20,
+			anchor=N, image=g.buttons["sword_pointer.png"], tags="monster_arrow")
 	main.recalc_stats(1)
 
 	#clear and rebuild listbox_item
@@ -91,17 +102,22 @@ def refresh():
 
 #attack button was pressed
 def attack(event=0):
+	global active_button
+	if can_leave() == 1: return 0
+	if active_button == -1: last_mon_num = select_monster()
+	else: last_mon_num = active_button
+	if last_mon_num == -1: return 0
 	global cur_button
 	cur_button = 0
-	if can_leave() == 1: return 0
-	last_mon_num = select_monster()
-	if last_mon_num == -1: return 0
+	clear_slashes()
 
 	#Both hp's *should* be over 0. Just a precaution.
 	if monster_list[last_mon_num].hp > 0 and g.hp > 0:
 		attack_monster(last_mon_num)
 	attack_player()
 	if can_leave() == 0:
+		active_button = -1
+		monster_mouse_move(event)
 		refresh()
 		refresh_buttons()
 
@@ -134,27 +150,23 @@ def select_monster():
 	global return_from_dialog
 	return_from_dialog.set("0")
 
-	canvas_mon_pic.create_image(
-		base_mon_hp_start[active_button],
-		base_mon_hp_y_start[active_button]-20,
-		anchor=N, image=monster_select_arrow, tags="monster_arrow")
 	#bindings
 	bind_attack_keys()
 
+	refresh()
 	#wait. Continue after activate_yesno() is run.
 	window_battle.wait_variable(return_from_dialog)
 	#cleanup
 	if return_from_dialog.get() == "2":
 		return -1
 	else:
-		try: canvas_mon_pic.delete("monster_arrow")
-		except TclError: pass
 		bind_keys()
 
 		action.has_dialog = 0
+		refresh()
 		return active_button
 
-#Cycle through the various monsters when attacking.
+#Cycle through the various monsters when attacking. Used by the keyboard.
 def choose_monster_prev(event=None):
 	global active_button
 	i = active_button
@@ -167,11 +179,10 @@ def choose_monster_prev(event=None):
 			break
 		if i == active_button:
 			print "choose_monster_prev couldn't find a monster."
-			return 0
-	canvas_mon_pic.coords(canvas_mon_pic.find_withtag("monster_arrow"),
-				base_mon_hp_start[i],
-				base_mon_hp_y_start[i]-20)
+			active_button = -1
+			return -1
 	help_text.set("Attack the " + monster_list[active_button].name)
+	refresh()
 
 def choose_monster_next(event=None):
 	global active_button
@@ -185,11 +196,10 @@ def choose_monster_next(event=None):
 			break
 		if i == active_button:
 			print "choose_monster_next couldn't find a monster."
-			return 0
-	canvas_mon_pic.coords(canvas_mon_pic.find_withtag("monster_arrow"),
-				base_mon_hp_start[i],
-				base_mon_hp_y_start[i]-20)
+			active_button = -1
+			return -1
 	help_text.set("Attack the " + monster_list[active_button].name)
+	refresh()
 
 #called on Return when the yesno dialog box is active.
 def choose_monster(event=None):
@@ -198,26 +208,27 @@ def choose_monster(event=None):
 
 #Cancels the monster selection. Called on Esc.
 def cancel_monster(event=None):
+	global active_button
+	active_button = -1
 	global return_from_dialog
-	return_from_dialog.set("2")
-
+	return_from_dialog.set("1")
 
 #Called whenever the mouse moves in the monster canvas. Used to select the
 #proper monster, given the x and y location of the mouse.
 def monster_mouse_move(event=None):
-	global active_button
-	for i in range(len(monster_list)):
-		if monster_list[i].hp > 0:
-			if event.x >= base_mon_hp_start[i] and \
-			event.x <= base_mon_hp_start[i] + base_mon_hp_width[i] and \
-			event.y >= base_mon_hp_y_start[i] - base_mon_hp_height[i] and \
-			event.y <= base_mon_hp_y_start[i]:
-				active_button = i
-				canvas_mon_pic.coords(
-						canvas_mon_pic.find_withtag("monster_arrow"),
-						base_mon_hp_start[i],
-						base_mon_hp_y_start[i]-20)
-				help_text.set("Attack the " + monster_list[i].name)
+	try:
+		global active_button
+		for i in range(len(monster_list)):
+			if monster_list[i].hp > 0:
+				if event.x >= base_mon_hp_start[i] and \
+				event.x <= base_mon_hp_start[i] + base_mon_hp_width[i] and \
+				event.y >= base_mon_hp_y_start[i] - base_mon_hp_height[i] and \
+				event.y <= base_mon_hp_y_start[i]:
+					active_button = i
+					help_text.set("Attack the " + monster_list[i].name)
+					refresh()
+	except AttributeError:
+		active_button = -1
 
 #attack the i'th monster in monster_list[].
 def attack_monster(i):
@@ -230,6 +241,7 @@ def attack_monster(i):
  		main.print_message("You hit the " + monster_list[i].name +
  			" for " + str(damage) + " damage.")
 		monster_list[i].hp = monster_list[i].hp - damage
+		monster_slashed(i)
 		#you kill it?
 		if monster_list[i].hp <= 0:
 			monster_dead(i)
@@ -253,6 +265,7 @@ def attack_player_per_monster(i):
 		main.print_message("The " + monster_list[i].name +
 		" hits you for " + str(damage) + " damage.")
 		g.hp = g.hp - damage
+		monster_slashed("h")
 		#you dead yet?
 		if g.hp <= 0:
 			g.hp = 0
@@ -267,6 +280,28 @@ def attack_player_per_monster(i):
 		" misses you.")
 
 
+#places a slash mark over the i'th monster, to indicate a hit, or "h" for the
+#hero.
+def monster_slashed(i):
+	if len(canvas_mon_pic.find_withtag("hit"+str(i))) == 0:
+		if str(i) == "h":
+			x, y = canvas_mon_pic.coords(canvas_mon_pic.find_withtag("hero"))
+			canvas_mon_pic.create_image(
+				x,
+				y+g.tiles["people/hero_n.png"].height()/2,
+				anchor=CENTER, image=g.buttons["slash_attack.png"], tags="hit"+str(i))
+		else:
+			canvas_mon_pic.create_image(
+				base_mon_hp_start[active_button]+base_mon_hp_width[active_button]/2,
+				base_mon_hp_y_start[active_button]-10,
+				anchor=S, image=g.buttons["slash_attack.png"], tags="hit"+str(i))
+
+#clears slashmark for monster i
+def clear_slashes():
+	for i in range(len(monster_list)):
+		canvas_mon_pic.delete(canvas_mon_pic.find_withtag("hit"+str(i)))
+	canvas_mon_pic.delete(canvas_mon_pic.find_withtag("hith"))
+
 #use to reward the player for killing a monster
 def monster_dead(i):
 	#make the display look better
@@ -315,6 +350,7 @@ def can_leave():
 #run/leave/quit button was pressed
 def runaway():
 	global run_attempts
+	clear_slashes()
 	try:
 		#leave/quit
 		if can_leave() == 1:
@@ -342,6 +378,7 @@ def useitem():
 	if can_leave() == 1:
 		return 0
 
+	clear_slashes()
 	#put the name of the item into item_name
 	if (len(listbox_item.curselection()) == 0): return 0
 
@@ -377,6 +414,7 @@ def useitem():
 			if damage > 0:
 				main.print_message("The " + monster_list[sel_mon].name +
 					" is hit for " + str(damage) + " damage.")
+				monster_slashed(sel_mon)
 			monster_list[sel_mon].hp = monster_list[sel_mon].hp - damage
 			#you kill it?
 			if monster_list[sel_mon].hp <= 0:
@@ -403,6 +441,7 @@ def useskill():
 	if can_leave() == 1:
 		return 0
 
+	clear_slashes()
 	#get the skill name.
 	if (len(listbox_skill.curselection()) == 0): return 0
 
@@ -445,21 +484,26 @@ def useskill():
 			main.print_message("You fail to sneak away.")
 			attack_player()
 	elif g.skill[skill_index][1] == 2: #Frenzy
+		mon_num = select_monster()
 		for i in range(3 + int(g.level)/3):
-			mon_num = select_monster()
+			if monster_list[mon_num].hp < 1:
+				mon_num = select_monster()
 			if mon_num == -1: return 0
 			attack_monster(mon_num)
 			if can_leave() == 1:
-#				monster_dead()
 				return 0
+			active_button = -1
+			monster_mouse_move()
 			refresh()
 		if can_leave() == 0: attack_player()
 	elif g.skill[skill_index][1] == 3: #Dismember
 		mon_num = select_monster()
 		if mon_num == -1: return 0
 		damage = (g.adj_attack * 5)/2
-		main.print_message("You hit the " + monster_list[mon_num].name +
-			" for " + str(damage) + " damage.")
+		if damage > 0:
+			main.print_message("You hit the " + monster_list[mon_num].name +
+				" for " + str(damage) + " damage.")
+			monster_slashed(mon_num)
 		monster_list[mon_num].hp = monster_list[mon_num].hp - damage
 		#you kill it?
 		if monster_list[mon_num].hp <= 0:
@@ -467,6 +511,8 @@ def useskill():
 		attack_player()
 
 	if can_leave() == 1: return 0
+	active_button = -1
+	monster_mouse_move()
 	refresh()
 
 	#replace the cursor
@@ -485,36 +531,36 @@ def refresh_buttons():
 
 	if (cur_button == 0):
 		canvas_buttons.create_image(attack_button_loc, 0, anchor=NW,
-					image=attack_button_sel)
+					image=g.buttons["attack_sel.png"])
 #FIX for multimonster
 		help_text.set("Attack the " + monster_list[cur_monster].name)
 	else: canvas_buttons.create_image(attack_button_loc, 0, anchor=NW,
-					image=attack_button)
+					image=g.buttons["attack.png"])
 	if (cur_button == 1):
 		if g.hp <= 0:
 			canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
-				image=quit_button_sel)
+				image=g.buttons["quit_sel.png"])
 			help_text.set("Quit")
 		elif can_leave() == 0:
 			canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
-				image=run_button_sel)
+				image=g.buttons["run_sel.png"])
 			help_text.set("Run away")
 		else:
 			canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
-				image=leave_button_sel)
+				image=g.buttons["leave_sel.png"])
 			help_text.set("Leave")
 	elif g.hp <= 0: canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
-			image=quit_button)
+			image=g.buttons["quit.png"])
 	elif can_leave == 0:
 		canvas_buttons.create_image(run_button_loc,
-			0, anchor=NW, image=run_button)
+			0, anchor=NW, image=g.buttons["run.png"])
 	else: canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
-			image=leave_button)
+			image=g.buttons["leave.png"])
 
 	if (cur_button == 2):
 		listbox_skill.select_clear(0, END)
 		canvas_buttons.create_image(item_button_loc, 0,
-			anchor=NW, image=item_button_sel)
+			anchor=NW, image=g.buttons["use_sel.png"])
 		if (len(listbox_item.curselection()) == 0):
 			help_text.set("No items")
 		else:
@@ -523,12 +569,12 @@ def refresh_buttons():
 			item_name = listbox_item.get(item_num[0])
 			help_text.set("Use your " + item_name)
 	else: canvas_buttons.create_image(item_button_loc, 0,
-			anchor=NW, image=item_button)
+			anchor=NW, image=g.buttons["use.png"])
 
 	if (cur_button == 3):
 		listbox_item.select_clear(0, END)
 		canvas_buttons.create_image(skill_button_loc, 0,
-			anchor=NW, image=skill_button_sel)
+			anchor=NW, image=g.buttons["skill_sel.png"])
 		if (len(listbox_skill.curselection()) == 0):
 			help_text.set("No useable skills")
 		else:
@@ -537,7 +583,7 @@ def refresh_buttons():
 			skill_name = listbox_skill.get(skill_num[0])
 			help_text.set("Use " + skill_name)
 	else: canvas_buttons.create_image(skill_button_loc, 0,
-			anchor=NW, image=skill_button)
+			anchor=NW, image=g.buttons["skill.png"])
 
 
 #All keypresses in window_shop pass through here. Based on the key name,
@@ -706,8 +752,8 @@ def battle_show_yesno(line=""):
 	global return_from_dialog
 	return_from_dialog.set("0")
 
-	canvas_width = no_button.width()*4/3+yes_button.width()*4/3
-	canvas_height = yes_button.height()+50
+	canvas_width = g.buttons["no.png"].width()*4/3+g.buttons["yes.png"].width()*4/3
+	canvas_height = g.buttons["yes.png"].height()+50
 	global canvas_battle2
 	canvas_battle2 = Canvas(window_battle, width=canvas_width,
 		height=canvas_height, highlightthickness=0)
@@ -721,9 +767,9 @@ def battle_show_yesno(line=""):
 		width=canvas_width-6, tags="dialogtxt")
 	#buttons
 	canvas_battle2.create_image(canvas_width/2,
-		canvas_height, image=no_button_sel, anchor="se", tags="no")
+		canvas_height, image=g.buttons["no_sel.png"], anchor="se", tags="no")
 	canvas_battle2.create_image(canvas_width/2,
-		canvas_height, image=yes_button, anchor="sw", tags="yes")
+		canvas_height, image=g.buttons["yes.png"], anchor="sw", tags="yes")
 	#bindings
 	main.window_main.bind(g.binding_up, change_yesno_sel)
 	main.window_main.bind(g.binding_right, change_yesno_sel)
@@ -756,15 +802,15 @@ def battle_show_yesno(line=""):
 def change_yesno_to_yes(event=None):
 	global active_button
 	active_button = 1
-	canvas_battle2.itemconfigure("no", image=no_button)
-	canvas_battle2.itemconfigure("yes", image=yes_button_sel)
+	canvas_battle2.itemconfigure("no", image=g.buttons["no.png"])
+	canvas_battle2.itemconfigure("yes", image=g.buttons["yes_sel.png"])
 
 #when a yesno dialog box is active, switch to no.
 def change_yesno_to_no(event=None):
 	global active_button
 	active_button = 0
-	canvas_battle2.itemconfigure("no", image=no_button_sel)
-	canvas_battle2.itemconfigure("yes", image=yes_button)
+	canvas_battle2.itemconfigure("no", image=g.buttons["no_sel.png"])
+	canvas_battle2.itemconfigure("yes", image=g.buttons["yes.png"])
 
 #when a yesno dialog box is active, switch the yes and no buttons.
 def change_yesno_sel(event=None):
@@ -803,27 +849,12 @@ def begin(mon_index_input):
 	cur_monster = 0
 	global run_attempts
 	run_attempts = 0
-
-	global yes_button; global yes_button_sel
-	global no_button; global no_button_sel
-	yes_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/yes.png")
-	no_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/no.png")
-	yes_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-                "/images/buttons/yes_sel.png")
-	no_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-                "/images/buttons/no_sel.png")
-
-	global monster_select_arrow
-	monster_select_arrow = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/sword_pointer.png")
+	global active_button
+	active_button = -1
 
 	# Set the current window
 	g.cur_window = "battle"
 
-
-
 	global canvas_desc
 	canvas_desc = Canvas(window_battle, width=200, height=190,
 		highlightthickness=0, bg=bgcolour)
@@ -849,14 +880,13 @@ def begin(mon_index_input):
 	global base_mon_hp_y_start
 	base_mon_hp_y_start = []
 	for i in range(len(monster_list)):
-		if os.path.isfile(g.mod_directory +
-				"/images/tiles/monsters/" + monster_list[i].name + ".png"):
-			monster_pic.append(ImageTk.PhotoImage(file=g.mod_directory +
-				"/images/tiles/monsters/" + monster_list[i].name + ".png"))
-		else:
-			monster_pic.append(ImageTk.PhotoImage(file=g.mod_directory +
-				"/images/tiles/monsters/generic.png"))
-#FIX
+		try:monster_pic.append(g.tiles[
+							"monsters/" + monster_list[i].name + ".png"])
+		except KeyError: monster_pic.append(g.tiles["monsters/generic.png"])
+
+		#if x and y positions were given, use them; otherwise, start at the
+		#middle, and go right. This works for 1 or two monsters, but xy
+		#coords are recommended for more.
 		if len(monster.monster_groups[mon_index].x_pos) > i:
 			xstart = monster.monster_groups[mon_index].x_pos[i]
 		else: xstart = background_pic.width()/2+i*40
@@ -883,13 +913,12 @@ def begin(mon_index_input):
 		canvas_mon_pic.create_text(xstart,
 			base_mon_hp_y_start[i]+7, anchor=N, text="", tags="mon_hp"+str(i))
 
-	if os.path.isfile(g.mod_directory + "/images/tiles/people/hero_n.png"):
-		hero_pic = ImageTk.PhotoImage(file=g.mod_directory +
-					"/images/tiles/people/hero_n.png")
-		canvas_mon_pic.create_image(
+	try: hero_pic = g.tiles["people/hero_n.png"]
+	except KeyError: hero_pic = ImageTk.PhotoImage("RGB", (32, 32))
+	canvas_mon_pic.create_image(
 				background_pic.width()/2,
 				background_pic.height()-hero_pic.height()-5,
-				anchor=N, image=hero_pic)
+				anchor=N, image=hero_pic, tags="hero")
 
 
 #FIX for multimonster
@@ -918,55 +947,18 @@ def begin(mon_index_input):
 	button_frame = Frame(window_battle, bg=bgcolour)
 	button_frame.grid(row=14, column=1, columnspan=2, sticky="NSEW")
 
-	#Attack and run buttons.
-	global attack_button; global attack_button_sel
-	global run_button; global run_button_sel
-	global quit_button; global quit_button_sel
-	global leave_button; global leave_button_sel
-	global item_button; global item_button_sel
-	global skill_button; global skill_button_sel
-
-	attack_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/attack.png")
-	run_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/run.png")
-	attack_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/attack_sel.png")
-	run_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/run_sel.png")
-	quit_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/quit_battle.png")
-	leave_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/leave.png")
-	item_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/use.png")
-	skill_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/skill.png")
-	quit_button_sel = \
-		ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/quit_battle_sel.png")
-	leave_button_sel = \
-		ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/leave_sel.png")
-	item_button_sel = \
-		ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/use_sel.png")
-	skill_button_sel = \
-		ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/skill_sel.png")
 
 	global item_button_loc
 	global skill_button_loc
 	global run_button_loc
-	item_button_loc = attack_button.width()
-	skill_button_loc = item_button_loc + item_button.width()
-	run_button_loc = skill_button_loc + skill_button.width()
+	item_button_loc = g.buttons["attack.png"].width()
+	skill_button_loc = item_button_loc + g.buttons["use.png"].width()
+	run_button_loc = skill_button_loc + g.buttons["skill.png"].width()
 
 	global canvas_buttons
 	canvas_buttons = Canvas(button_frame, bg="#b3b3b3",
-		height=attack_button.height(),
-		width=attack_button.width() + run_button.width() +
-		item_button.width() + skill_button.width())
+		height=g.buttons["attack.png"].height(),
+		width=run_button_loc + g.buttons["run.png"].width())
 	canvas_buttons.grid(column=1, row=1, sticky="NSEW")
 
 	#use item listbox
@@ -982,9 +974,6 @@ def begin(mon_index_input):
 	item_scroll.grid(row=9, column=1, rowspan=5, sticky=N+S+E)
 	listbox_item.config(yscrollcommand=item_scroll.set)
 
-	#use skill listbox
-#	skill_frame = Frame(window_battle, background="#003300")
-#	skill_frame.grid(row=9, column=3, sticky=N+S+E+W)
 
 	skill_label = Label(window_battle, text='Skills', bg=bgcolour)
 	skill_label.grid(row=9, column=2, sticky=N)
@@ -1031,6 +1020,8 @@ def bind_keys():
 	canvas_buttons.bind("<Motion>", mouse_handler_move)
 	listbox_item.bind("<ButtonRelease-1>", mouse_handler_item)
 	listbox_skill.bind("<ButtonRelease-1>", mouse_handler_skill)
+	canvas_mon_pic.bind("<ButtonRelease-1>", attack)
+	canvas_mon_pic.bind("<Motion>", monster_mouse_move)
 
 #keybindings when choosing a monster to attack.
 def bind_attack_keys():
