@@ -110,6 +110,7 @@ binding_quit="q"
 binding_inv="i"
 binding_inv_right="<Next>"
 binding_inv_left="<Prior>"
+message_lines = 6
 
 #save the game in saves/input.
 #uses pickle, first line is a version number.
@@ -256,6 +257,7 @@ def init_data():
 	read_variables()
 	read_shops()
 	read_perturn()
+	load_buttons()
 
 #Get the name of the module from the variables.txt file. Note that this
 #does not set the game name, only returns it. This lets it be used in rpg.py
@@ -289,6 +291,7 @@ def read_settings():
 	global binding_inv
 	global binding_inv_right
 	global binding_inv_left
+	global message_lines
 
 	#try to open settings.txt. If it doesn't exist,
 	# just use the default settings.
@@ -324,6 +327,8 @@ def read_settings():
 			binding_inv_right = line.split("=", 1)[1].strip()
 		if (line.split("=", 1)[0].strip() == "inv_left"):
 			binding_inv_left = line.split("=", 1)[1].strip()
+		if (line.split("=", 1)[0].strip() == "message_lines"):
+			message_lines = line.split("=", 1)[1].strip()
 		line = file.readline()
 
 
@@ -481,10 +486,10 @@ def checklocation(x, y):
 		#off the map, so rock.
 		return 'a'
 
-#like checklocation, but just returns 0 (rock) or 1 (grass)
+#like checklocation, but just returns 0 (unwalkable) or 1 (walkable)
 def iswalkable(x, y):
 
-	#Assume that all off-map areas are rock.
+	#Assume that all off-map areas (to north or west) are unwalkable.
 	if x < 0 or y < 0:
 		return 0
 	try:
@@ -510,41 +515,30 @@ tiles = {}
 #this loads the various tiles.
 def load_tiles():
 	global tiles
-	tiles = {"blank" : ImageTk.PhotoImage("RGB", (32, 32))}
-
-	for root, dirs, files in walk(g.mod_directory + "/images/tiles/"):
-		(head, tail) = path.split(root)
-		if (tail != "CVS"):
-			for tilename in files:
-				#if image is in a sub-dir:
-				if (root != g.mod_directory + "/images/tiles/"):
-					i = len(g.mod_directory + "/images/tiles/")
-					tiles[root[i:] + "/" + tilename] = \
-						ImageTk.PhotoImage(file=root + "/" + tilename)
-				else: #if image is in root dir
-					tiles[tilename] = \
-						ImageTk.PhotoImage(file=root + "/" + tilename)
-
+	temp_images = read_images("/images/tiles/")
+	tiles = {}
+	for image_name, image in temp_images.iteritems():
+		tiles[image_name] = image
 
 backgrounds = {}
 
 #This loads the battle backgrounds.
 def load_backgrounds():
 	global backgrounds
-	backgrounds = {"blank" : ImageTk.PhotoImage("RGB", (200, 200))}
+	temp_images = read_images("/images/backgrounds/")
+	backgrounds = {}
+	for image_name, image in temp_images.iteritems():
+		backgrounds[image_name] = image
 
-	for root, dirs, files in walk(g.mod_directory + "/images/backgrounds/"):
-		(head, tail) = path.split(root)
-		if (tail != "CVS"):
-			for tilename in files:
-				#if image is in a sub-dir:
-				if (root != g.mod_directory + "/images/backgrounds/"):
-					i = len(g.mod_directory + "/images/backgrounds/")
-					backgrounds[root[i:] + "/" + tilename] = \
-						ImageTk.PhotoImage(file=root + "/" + tilename)
-				else: #if image is in root dir
-					backgrounds[tilename] = \
-						ImageTk.PhotoImage(file=root + "/" + tilename)
+buttons = {}
+
+#This loads the buttons.
+def load_buttons():
+	global buttons
+	temp_images = read_images("/images/buttons/")
+	buttons = {}
+	for image_name, image in temp_images.iteritems():
+		buttons[image_name] = image
 
 
 #given a filename, return the script contained in the file.
@@ -576,3 +570,21 @@ def read_script_file(file_name):
 	file.close()
 	return temp_array
 
+#given a directory relative to g.mod_directory, will return a dictionary
+#of all images in that directory, and all subdirectories.
+def read_images(dir_name):
+	image_dictionary =  {"blank" : ImageTk.PhotoImage("RGB", (32, 32))}
+	for root, dirs, files in walk(g.mod_directory + dir_name):
+		(head, tail) = path.split(root)
+		if (tail != "CVS"):
+			for tilename in files:
+				#if image is in a sub-dir:
+				if (root != g.mod_directory + dir_name):
+					i = len(g.mod_directory + dir_name)
+					image_dictionary[root[i:] + "/" + tilename] = \
+						ImageTk.PhotoImage(file=root + "/" + tilename)
+				else: #if image is in root dir
+					image_dictionary[tilename] = \
+						ImageTk.PhotoImage(file=root + "/" + tilename)
+	return image_dictionary
+
