@@ -31,7 +31,6 @@ mapsizey = 13
 sidebarsize = 5
 status_box_width = 19
 width = 20
-status_box_height =6
 tilesize = 32
 
 #division is nasty. Only do it once. Used for centering items on the player.
@@ -47,7 +46,7 @@ global already_refreshed
 already_refreshed = 0
 
 #max number of messages to keep.
-max_messages = 20
+max_messages = 25
 
 #number of free moves after attack left.
 global free_move
@@ -294,10 +293,10 @@ def move_hero(x, y):
 				g.xgrid=g.xgrid + x
 				g.ygrid=g.ygrid + y
 				passturn()
-				if y == -1: g.cur_hero = "people/hero_n.png"
-				if y ==  1: g.cur_hero = "people/hero_s.png"
-				if x == -1: g.cur_hero = "people/hero_w.png"
-				if x ==  1: g.cur_hero = "people/hero_e.png"
+				if y == -1: g.cur_hero = "people/hero_n" + g.maps[g.zgrid].hero_suffix + ".png"
+				if y ==  1: g.cur_hero = "people/hero_s" + g.maps[g.zgrid].hero_suffix + ".png"
+				if x == -1: g.cur_hero = "people/hero_w" + g.maps[g.zgrid].hero_suffix + ".png"
+				if x ==  1: g.cur_hero = "people/hero_e" + g.maps[g.zgrid].hero_suffix + ".png"
 				#Sometimes, quick refresh is bad.
 				global already_refreshed
 				if already_refreshed == 1:
@@ -329,10 +328,10 @@ def move_hero(x, y):
 
 		else:
 			if (tempx == g.xgrid + x) and (tempy == g.ygrid + y):
-				if y == -1: g.cur_hero = "people/hero_n.png"
-				if y ==  1: g.cur_hero = "people/hero_s.png"
-				if x == -1: g.cur_hero = "people/hero_w.png"
-				if x ==  1: g.cur_hero = "people/hero_e.png"
+				if y == -1: g.cur_hero = "people/hero_n" + g.maps[g.zgrid].hero_suffix + ".png"
+				if y ==  1: g.cur_hero = "people/hero_s" + g.maps[g.zgrid].hero_suffix + ".png"
+				if x == -1: g.cur_hero = "people/hero_w" + g.maps[g.zgrid].hero_suffix + ".png"
+				if x ==  1: g.cur_hero = "people/hero_e" + g.maps[g.zgrid].hero_suffix + ".png"
 			refreshhero()
 			recalc_stats()
 		g.allow_move = 1
@@ -416,20 +415,21 @@ def show_dialog(line=None):
 	#text
 	canvas_map.create_text((mapsizex*tilesize/2),
 		(6*mapsizey*tilesize/7), text=line, anchor="s",
-		width=no_button.width()*4/3+yes_button.width()*4/3-6, tags="dialogtxt")
+		width=(g.buttons["no.png"].width()+g.buttons["yes.png"].width())*4/3-6,
+		tags="dialogtxt")
 	#generate the background size.
 	x1, y1, x2, y2 = canvas_map.bbox("dialogtxt")
-	if x1 > (mapsizex*tilesize/2) - no_button.width():
-		x1 = (mapsizex*tilesize/2) - no_button.width()
-	if x2 < (mapsizex*tilesize/2) + yes_button.width():
-		x2 = (mapsizex*tilesize/2) + yes_button.width()
+	if x1 > (mapsizex*tilesize/2) - g.buttons["no.png"].width():
+		x1 = (mapsizex*tilesize/2) - g.buttons["no.png"].width()
+	if x2 < (mapsizex*tilesize/2) + g.buttons["yes.png"].width():
+		x2 = (mapsizex*tilesize/2) + g.buttons["yes.png"].width()
 	#background
-	canvas_map.create_rectangle(x1-5, y1-5, x2+5, y2+no_button.height(),
+	canvas_map.create_rectangle(x1-5, y1-5, x2+5, y2+g.buttons["no.png"].height(),
 		fill=g.fill_colour, outline="Black", tags="background_box")
 	canvas_map.lift("dialogtxt")
 	#button
 	canvas_map.create_image((mapsizex*tilesize/2),
-		(6*mapsizey*tilesize/7), image=begin_button_sel, anchor="n", tags="ok")
+		(6*mapsizey*tilesize/7), image=g.buttons["begin_sel.png"], anchor="n", tags="ok")
 	#bindings
 	window_main.bind(g.binding_action, activate_yesno)
 	canvas_map.tag_bind("ok", "<Button-1>", activate_yesno)
@@ -458,22 +458,22 @@ def show_yesno(line=""):
 	#text
 	canvas_map.create_text((mapsizex*tilesize/2),
 		(6*mapsizey*tilesize/7), text=line, anchor="s",
-		width=no_button.width()*4/3+yes_button.width()*4/3-6, tags="dialogtxt")
+		width=g.buttons["no.png"].width()*4/3+g.buttons["yes.png"].width()*4/3-6, tags="dialogtxt")
 	#generate the background size.
 	x1, y1, x2, y2 = canvas_map.bbox("dialogtxt")
-	if x1 > (mapsizex*tilesize/2) - no_button.width():
-		x1 = (mapsizex*tilesize/2) - no_button.width()
-	if x2 < (mapsizex*tilesize/2) + yes_button.width():
-		x2 = (mapsizex*tilesize/2) + yes_button.width()
+	if x1 > (mapsizex*tilesize/2) - g.buttons["no.png"].width():
+		x1 = (mapsizex*tilesize/2) - g.buttons["no.png"].width()
+	if x2 < (mapsizex*tilesize/2) + g.buttons["yes.png"].width():
+		x2 = (mapsizex*tilesize/2) + g.buttons["yes.png"].width()
 	#background
-	canvas_map.create_rectangle(x1-5, y1-5, x2+5, y2+no_button.height(),
+	canvas_map.create_rectangle(x1-5, y1-5, x2+5, y2+g.buttons["no.png"].height(),
 		fill=g.fill_colour, outline="Black", tags="background_box")
 	canvas_map.lift("dialogtxt")
 	#buttons
 	canvas_map.create_image((mapsizex*tilesize/2),
-		(6*mapsizey*tilesize/7), image=no_button_sel, anchor="ne", tags="no")
+		(6*mapsizey*tilesize/7), image=g.buttons["no_sel.png"], anchor="ne", tags="no")
 	canvas_map.create_image((mapsizex*tilesize/2),
-		(6*mapsizey*tilesize/7), image=yes_button, anchor="nw", tags="yes")
+		(6*mapsizey*tilesize/7), image=g.buttons["yes.png"], anchor="nw", tags="yes")
 	#bindings
 	window_main.bind(g.binding_up, change_yesno_sel)
 	window_main.bind(g.binding_right, change_yesno_sel)
@@ -501,15 +501,15 @@ def show_yesno(line=""):
 def change_yesno_to_yes(event=None):
 	global active_button
 	active_button = 1
-	canvas_map.itemconfigure("no", image=no_button)
-	canvas_map.itemconfigure("yes", image=yes_button_sel)
+	canvas_map.itemconfigure("no", image=g.buttons["no.png"])
+	canvas_map.itemconfigure("yes", image=g.buttons["yes_sel.png"])
 
 #when a yesno dialog box is active, switch to no.
 def change_yesno_to_no(event=None):
 	global active_button
 	active_button = 0
-	canvas_map.itemconfigure("no", image=no_button_sel)
-	canvas_map.itemconfigure("yes", image=yes_button)
+	canvas_map.itemconfigure("no", image=g.buttons["no_sel.png"])
+	canvas_map.itemconfigure("yes", image=g.buttons["yes.png"])
 
 #when a yesno dialog box is active, switch the yes and no buttons.
 def change_yesno_sel(event=None):
@@ -548,7 +548,7 @@ def init_window_main(new_game = 0):
 	#status window, scrollbar
 	global move_scroll
 	global listbox_status
-	listbox_status = Listbox(window_main, height=status_box_height,
+	listbox_status = Listbox(window_main, height=g.message_lines,
 		bg=statusboxcolour)
 	listbox_status.grid(row=1, column=0, sticky=N+S+E+W) #status_box_width)
 	move_scroll = Scrollbar(window_main, orient=VERTICAL,
@@ -565,21 +565,6 @@ def init_window_main(new_game = 0):
 
 	name.set(g.name)
 
-	#yes/no buttons for dialogs.
-	global yes_button; global yes_button_sel
-	yes_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/yes.png")
-	yes_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/yes_sel.png")
-	global no_button; global no_button_sel
-	no_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/no.png")
-	no_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/no_sel.png")
-	global begin_button_sel
-	begin_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/begin_sel.png")
-
 	#left (stats) side frame
 	global left
 	left = Frame(top, bg=bgcolour);
