@@ -141,7 +141,7 @@ def move_right(event=None):
 	refresh_map()
 
 def map_callback(event):
-	if(cur_tile != "" or cur_mode == "remove" or cur_mode == "walkable"):
+	if(cur_tile != "" or cur_mode == "remove" or cur_mode == "walkable" or cur_mode == "scripting"):
 		set_tile((event.x / g.tilesize)+portal_x, (event.y / g.tilesize)+portal_y, cur_tile)
 
 #set mode to add, replace, remove, or walkable
@@ -184,11 +184,12 @@ def set_border(edge):
 
 	refresh_map()
 
-#refresh map.
+#refresh map. This refreshes every tile, as accuracy is rather important here.
+#(compared to the main game)
 def refresh_map():
 	canvas_map.delete(ALL)
 	for y in range(portal_y, portal_y+portalsize):
-		if y >= mapsize_y: return
+		if y >= mapsize_y: break
 		for x in range(portal_x, portal_x+portalsize):
 			if x >= mapsize_x: break
 			for line in cur_map.field[y][x].onload:
@@ -202,10 +203,13 @@ def refresh_map():
 					canvas_map.create_image((x-portal_x)*g.tilesize,
 						(y-portal_y)*g.tilesize, anchor=NW,
 						image=g.tiles[line.strip().split()[7].strip()])
-	#if we are adjusting walkable status, display black/white box on tile
+	#If we are adjusting walkable status, display black/white box on tile.
+	#White for walkable, Black for non. Note that if the walkable status
+	#depends on an if statement, this may have incorrect results. (No good
+	#way to fix this, though.)
 	if cur_mode == "walkable":
 		for y in range(portal_y, portal_y+portalsize):
-			if y >= mapsize_y: return
+			if y >= mapsize_y: break
 			for x in range(portal_x, portal_x+portalsize):
 				if x >= mapsize_x: break
 				for line in cur_map.field[y][x].onload:
@@ -223,6 +227,34 @@ def refresh_map():
 							(x-portal_x)*g.tilesize + 2*g.tilesize/3,
 							(y-portal_y)*g.tilesize + 2*g.tilesize/3,
 							fill="black")
+	#If the tiles has some scripting, display a black-bordered white square.
+	#(To make sure it displays well on all tiles.)
+	#This ignores the pix and walk commands that all tiles must have.
+	if cur_mode == "scripting":
+		for y in range(portal_y, portal_y+portalsize):
+			if y >= mapsize_y: break
+			for x in range(portal_x, portal_x+portalsize):
+				if x >= mapsize_x: break
+				draw_boxes = 0
+				for line in cur_map.field[y][x].onload:
+					temp_command = line.split()[0].strip().lower()
+					if temp_command != "walk" and temp_command != "pix":
+						draw_boxes = 1
+				if len(cur_map.field[y][x].actions) > 0:
+					draw_boxes = 1
+				if draw_boxes == 1:
+					canvas_map.create_rectangle(
+						(x-portal_x)*g.tilesize + g.tilesize/3,
+						(y-portal_y)*g.tilesize + g.tilesize/3,
+						(x-portal_x)*g.tilesize + 2*g.tilesize/3,
+						(y-portal_y)*g.tilesize + 2*g.tilesize/3,
+						fill="black")
+					canvas_map.create_rectangle(
+						(x-portal_x)*g.tilesize + g.tilesize/3+3,
+						(y-portal_y)*g.tilesize + g.tilesize/3+3,
+						(x-portal_x)*g.tilesize + 2*g.tilesize/3-3,
+						(y-portal_y)*g.tilesize + 2*g.tilesize/3-3,
+						fill="white")
 	scroll_from_map()
 	#g.tilesize/3
 
@@ -247,6 +279,8 @@ def set_tile(x, y, name):
 				cur_map.field[y][x].onload[line_num] = "walk 0"
 			elif cur_map.field[y][x].onload[line_num] == "walk 0":
 				cur_map.field[y][x].onload[line_num] = "walk 1"
+	elif cur_mode == "scripting":
+		change_scripting(x, y)
 	else:
 		temp_name = name
 		for line_num in range(len(cur_map.field[y][x].onload)):
@@ -302,6 +336,50 @@ def really_set_amount(temp_amount):
 def close_amount_window():
 	amount_window.destroy()
 
+#given the x,y coords of the current tile, will display the onload and action
+#lines of the tile, and allow for editing.
+def change_scripting(x, y):
+	global scripting_window
+	scripting_window = Toplevel(window)
+	onload_textbox = Text(scripting_window, width=80, height=12)
+	onload_textbox.grid(row=0, column=0, columnspan=2)
+	action_textbox = Text(scripting_window, width=80, height=12)
+	action_textbox.grid(row=1, column=0, columnspan=2)
+	for line in cur_map.field[y][x].onload:
+		onload_textbox.insert(END, line + "\n")
+	for line in cur_map.field[y][x].actions:
+		action_textbox.insert(END, line + "\n")
+
+	ok_button = Button(scripting_window, text="OK",
+		command=(lambda: really_change_scripting(x, y,
+					onload_textbox.get(1.0, END),
+					action_textbox.get(1.0, END))))
+	ok_button.grid(row=3, column=0)
+	cancel_button = Button(scripting_window, text="Cancel",
+		command=(lambda: close_scripting_window()))
+	cancel_button.grid(row=3, column=1)
+	scripting_window.master.wait_window(scripting_window)
+
+def close_scripting_window():
+	scripting_window.destroy()
+
+#Given xy coords, and the scripting for a tile, each line separated by \n,
+#set the tile data.
+def really_change_scripting(x, y, onload, action):
+	onload_array = onload.split("\n")
+	action_array = action.split("\n")
+	cur_map.field[y][x].onload = []
+	for line in onload_array:
+		if line != "":
+			cur_map.field[y][x].onload.append(line)
+	cur_map.field[y][x].actions = []
+	for line in action_array:
+		if line != "":
+			cur_map.field[y][x].actions.append(line)
+	close_scripting_window()
+
+#Take the generic tkinter scrollbars, and turn them into something useful.
+#Scrollbar on right
 def map_from_scroll_y(scrolltype, step, what=None):
 	global portal_y
 	if scrolltype=="moveto":
@@ -322,6 +400,7 @@ def map_from_scroll_y(scrolltype, step, what=None):
 				if portal_y < 0: portal_y = 0
 			refresh_map()
 
+#Scrollbar on bottom
 def map_from_scroll_x(scrolltype, step, what=None):
 	global portal_x
 	if scrolltype=="moveto":
@@ -342,6 +421,7 @@ def map_from_scroll_x(scrolltype, step, what=None):
 				if portal_x < 0: portal_x = 0
 			refresh_map()
 
+#Take the current map position, and turn into useful scrollbars.
 def scroll_from_map():
 	scrolltop = float(portal_y)/mapsize_y
 	scrollbot = float((portal_y+portalsize))/mapsize_y
@@ -514,6 +594,9 @@ def save_map(event=0):
 		map_file.write("monster=" + monster_name + "\n")
 	if cur_map.battle_background_name != "":
 		map_file.write("battle_bg=" + cur_map.battle_background_name + "\n")
+	if cur_map.hero_suffix != "":
+		map_file.write("hero_bg=" + cur_map.hero_suffix + "\n")
+
 
 	#use the upper-left tile as background.
 	map_file.write(":a\n")
@@ -571,6 +654,7 @@ def copy_map(output_map, input_map):
 	for monster in input_map.monster:
 		output_map.monster.append(monster)
 	output_map.battle_background_name = input_map.battle_background_name
+	output_map.hero_suffix = input_map.hero_suffix
 
 #given input and output tiles, copies the important parts.
 def copy_tile(output_tile, input_tile):
@@ -608,7 +692,9 @@ def edit_monsters(i):
 	monster_textbox.grid(row=0, column=0, columnspan=2)
 
 	monster_background_textbox = Entry(monster_window)
-	monster_background_textbox.grid(row=1, column=0, columnspan=2)
+	monster_background_textbox.grid(row=1, column=1)
+	label_format = Label(monster_window, text="Battle Background:")
+	label_format.grid(row=1, column=0)
 	monster_background_textbox.delete(0, END)
 	monster_background_textbox.insert(END, cur_map.battle_background_name)
 
@@ -644,7 +730,9 @@ def close_monster_window():
 #brings up the change mapsize window.
 def change_mapsize(size):
 	temp_x = StringVar()
+	temp_x.set(mapsize_x)
 	temp_y = StringVar()
+	temp_y.set(mapsize_y)
 	global size_window
 	size_window = Toplevel(window)
 	label_format = Label(size_window, text="Width")
@@ -753,6 +841,7 @@ def make_menus():
 	mapmode_menu.add_command(label='Add Tile (transparency)', command=(lambda x="add":set_mode(x)))
 	mapmode_menu.add_command(label='Reset Tile (clear to background)', command=(lambda x="remove":set_mode(x)))
 	mapmode_menu.add_command(label='Adjust walkable staus', command=(lambda x="walkable":set_mode(x)))
+	mapmode_menu.add_command(label='Edit scripting', command=(lambda x="scripting":set_mode(x)))
 
 	#mapsize submenu
 	mapsize_menu = Menu(map_options, bg=bgcolour)
