@@ -64,6 +64,9 @@ class map:
 		#Filled in with a Tkinter image reference
 		self.battle_background = ""
 
+		#special hero pix
+		self.hero_suffix = ""
+
 		self.maptext = [] #unused after load
 		self.tiles = {} #unused after load
 		self.per_tile_info = [] #unused after load
@@ -101,6 +104,9 @@ class map:
 							g.backgrounds[map_line.split("=", 1)[1].strip()]
 						self.battle_background_name = \
 							map_line.split("=", 1)[1].strip()
+					elif map_command == "hero_bg":
+						self.hero_suffix = \
+							map_line.split("=", 1)[1].strip()
 					else:
 						print "bad command of " + map_command + " received"
 
