@@ -53,20 +53,20 @@ curr_skill = StringVar()
 #refresh the button canvas
 def refresh_buttons(event=0):
 	canvas_buttons.delete(ALL)
-	if (cur_button == 0):
-	    canvas_buttons.create_image(0, 0, anchor=NW, image=sell_button_sel)
-	else:
-	    canvas_buttons.create_image(sell_height, 0, anchor=NW, image=sell_button)
+	if (cur_button == 0): canvas_buttons.create_image(0, 0, anchor=NW,
+						image=g.buttons["sell_sel.png"])
+	else: canvas_buttons.create_image(sell_height, 0, anchor=NW,
+						image=g.buttons["sell.png"])
 
-	if (cur_button == 1):
-	    canvas_buttons.create_image(leave_height, 0, anchor=NW, image=leave_button_sel)
-	else:
-	    canvas_buttons.create_image(leave_height, 0, anchor=NW, image=leave_button)
+	if (cur_button == 1): canvas_buttons.create_image(leave_height, 0,
+			anchor=NW, image=g.buttons["leave_shop_sel.png"])
+	else: canvas_buttons.create_image(leave_height, 0, anchor=NW,
+						image=g.buttons["leave_shop.png"])
 
-	if (cur_button == 2):
-	    canvas_buttons.create_image(buy_height, 0, anchor=NW, image=buy_button_sel)
-	else:
-    	    canvas_buttons.create_image(buy_height, 0, anchor=NW, image=buy_button)
+	if (cur_button == 2): canvas_buttons.create_image(buy_height, 0, anchor=NW,
+						image=g.buttons["buy_sel.png"])
+	else: canvas_buttons.create_image(buy_height, 0, anchor=NW,
+						image=g.buttons["buy.png"])
 
 
 #refresh the inventory canvas
@@ -435,31 +435,12 @@ def init_window_shop(store_type_input):
 		bg=bgcolour).grid(row=19, column=3, sticky=W)
 
 
-	#Buttons
-	global sell_button; global sell_button_sel
-	global buy_button; global buy_button_sel
-	global leave_button; global leave_button_sel
-
-
-	sell_button =  ImageTk.PhotoImage(file=g.mod_directory + \
-	                "/images/buttons/sell.png")
-	sell_button_sel =  ImageTk.PhotoImage(file=g.mod_directory + \
-	                "/images/buttons/sell_sel.png")
-	buy_button =  ImageTk.PhotoImage(file=g.mod_directory + \
-	                "/images/buttons/buy.png")
-	buy_button_sel =  ImageTk.PhotoImage(file=g.mod_directory + \
-	                "/images/buttons/buy_sel.png")
-	leave_button =  ImageTk.PhotoImage(file=g.mod_directory + \
-	                "/images/buttons/leave_shop.png")
-	leave_button_sel =  ImageTk.PhotoImage(file=g.mod_directory + \
-	                "/images/buttons/leave_shop_sel.png")
-
-	global leave_height; leave_height = sell_button.width()
-	global buy_height; buy_height = leave_height + leave_button.width()
+	global leave_height; leave_height = g.buttons["sell.png"].width()
+	global buy_height; buy_height = leave_height + g.buttons["leave.png"].width()
 
 	global canvas_buttons
-	canvas_buttons = Canvas(window_shop, height=buy_button_sel.height(),
-		width=buy_height+buy_button.width(), bg=bgcolour)
+	canvas_buttons = Canvas(window_shop, height=g.buttons["buy.png"].height(),
+		width=buy_height+g.buttons["buy.png"].width(), bg=bgcolour)
 	canvas_buttons.grid(column=1, row=29, columnspan=8)
 
 
